@@ -65,23 +65,21 @@ datatable_template <- function(input_data) {
 library(dplyr)
 library(labelled)
 library(xportr)
-library(admiral)
-library(rlang)
 library(readxl)
 
 # Loading in our example data
-adsl <- admiral::admiral_adsl
+data("adsl_xportr", package = "xportr")
 
 ## ---- echo = FALSE----------------------------------------
-datatable_template(adsl)
+datatable_template(adsl_xportr)
 
 ## ---------------------------------------------------------
 var_spec <- read_xlsx(
-  system.file(paste0("specs/", "ADaM_admiral_spec.xlsx"), package = "xportr"),
+  system.file(file.path("specs/", "ADaM_spec.xlsx"), package = "xportr"),
   sheet = "Variables"
 ) %>%
   rename(type = "Data Type") %>%
-  set_names(tolower)
+  rename_with(tolower)
 
 ## ---- echo = FALSE, eval = TRUE---------------------------
 var_spec_view <- var_spec %>%
@@ -90,31 +88,31 @@ var_spec_view <- var_spec %>%
 datatable_template(var_spec_view)
 
 ## ----  max_height = "200px", echo = FALSE-----------------
-str(adsl)
+str(adsl_xportr)
 
 ## ---- echo = TRUE-----------------------------------------
-adsl_type <- xportr_type(adsl, var_spec, domain = "ADSL", verbose = "message")
+adsl_type <- xportr_type(adsl_xportr, var_spec, domain = "ADSL", verbose = "message")
 
 ## ----  max_height = "200px", echo = FALSE-----------------
 str(adsl_type)
 
 ## ----  max_height = "200px", echo = FALSE-----------------
-str(adsl)
+str(adsl_xportr)
 
 ## ---------------------------------------------------------
-adsl_length <- adsl %>% xportr_length(var_spec, domain = "ADSL", "message")
+adsl_length <- adsl_xportr %>% xportr_length(var_spec, domain = "ADSL", verbose = "message")
 
 ## ----  max_height = "200px", echo = FALSE-----------------
 str(adsl_length)
 
 ## ---- echo = TRUE-----------------------------------------
-adsl_order <- xportr_order(adsl, var_spec, domain = "ADSL", verbose = "message")
+adsl_order <- xportr_order(adsl_xportr, var_spec, domain = "ADSL", verbose = "message")
 
 ## ---- echo = FALSE----------------------------------------
 datatable_template(adsl_order)
 
 ## ---- max_height = "200px", echo = FALSE------------------
-adsl_fmt_pre <- adsl %>%
+adsl_fmt_pre <- adsl_xportr %>%
   select(TRTSDT, TRTEDT, TRTSDTM, TRTEDTM)
 
 tribble(
@@ -126,7 +124,7 @@ tribble(
 )
 
 ## ---------------------------------------------------------
-adsl_fmt <- adsl %>% xportr_format(var_spec, domain = "ADSL")
+adsl_fmt <- adsl_xportr %>% xportr_format(var_spec, domain = "ADSL")
 
 ## ---- max_height = "200px", echo = FALSE------------------
 adsl_fmt_post <- adsl_fmt %>%
@@ -141,22 +139,22 @@ tribble(
 )
 
 ## ----  max_height = "200px", echo = FALSE-----------------
-adsl_no_lbls <- haven::zap_label(adsl)
+adsl_no_lbls <- haven::zap_label(adsl_xportr)
 
 str(adsl_no_lbls)
 
 ## ---------------------------------------------------------
-adsl_lbl <- adsl %>% xportr_label(var_spec, domain = "ADSL", "message")
+adsl_lbl <- adsl_xportr %>% xportr_label(var_spec, domain = "ADSL", "message")
 
 ## ----  max_height = "200px"-------------------------------
 str(adsl_lbl)
 
 ## ---------------------------------------------------------
-adsl %>%
+adsl_xportr %>%
   xportr_type(var_spec, "ADSL", "message") %>%
-  xportr_length(var_spec, "ADSL", "message") %>%
+  xportr_length(var_spec, "ADSL", verbose = "message") %>%
   xportr_label(var_spec, "ADSL", "message") %>%
   xportr_order(var_spec, "ADSL", "message") %>%
   xportr_format(var_spec, "ADSL") %>%
-  xportr_write("adsl.xpt", label = "Subject-Level Analysis Dataset")
+  xportr_write("adsl.xpt")
 
